package cPanel;

use strict;
use warnings;

use version;our $VERSION = qv('0.0.1');

1;
__END__

=head1 NAME

cPanel - Perl extension to cPanel servers

=head1 SYNOPSIS

  use cPanel;

=head1 DESCRIPTION

This is a placeholder for now for cPanel:: modules.

I'm doing this as a cPanel L<http://www.cpanel.net> developer for future development of our public API.

=head1 USING THE cPanel:: namespace

If you'd like to use the cPanel namespace in your modules, please use cPanel::3rdparty, cPanel::Custom, cPanel::Local, or cPanel::My as your 
base namespace to avoid confusion with modules released by cPanel, Inc.

Thank you very much for your consideration in this matter.

=head1 AUTHOR

Daniel Muey, E<lt>http://drmuey.com/cpan_contact.pl<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2006 by Daniel Muey

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.6 or,
at your option, any later version of Perl 5 you may have available.

=cut
